@@ -1,43 +1,27 @@
 /*
-  Copyright (c) 2016-2019 Montel Laurent <montel@kde.org>
+  SPDX-FileCopyrightText: 2016-2021 Laurent Montel <montel@kde.org>
 
-  This program is free software; you can redistribute it and/or modify it
-  under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful, but
-  WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+  SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #ifndef AbstractGENERICPLUGININTERFACE_H
 #define AbstractGENERICPLUGININTERFACE_H
-#include <QObject>
 #include "pimcommon_export.h"
+#include <QObject>
 class QAction;
 class KActionCollection;
-namespace PimCommon {
+namespace PimCommon
+{
 class AbstractGenericPlugin;
 class GenericPlugin;
+/**
+ * @brief The ActionType class
+ * @author Laurent Montel <montel@kde.org>
+ */
 class PIMCOMMON_EXPORT ActionType
 {
 public:
-    enum Type {
-        Tools = 0,
-        Edit = 1,
-        File = 2,
-        Action = 3,
-        PopupMenu = 4,
-        ToolBar = 5,
-        Message = 6,
-        Folder = 7
-    };
+    enum Type { Tools = 0, Edit = 1, File = 2, Action = 3, PopupMenu = 4, ToolBar = 5, Message = 6, Folder = 7 };
     ActionType()
     {
     }
