@@ -18,7 +18,8 @@ class QAbstractItemModel;
 class QAction;
 class QItemSelectionModel;
 
-namespace PimCommon {
+namespace PimCommon
+{
 class PIMCOMMONAKONADI_TESTS_EXPORT AclManager : public QObject
 {
     Q_OBJECT
@@ -41,7 +42,7 @@ public:
     /**
      * Destroys the ACL manager.
      */
-    ~AclManager();
+    ~AclManager() override;
 
     /**
      * Sets the @p collection whose ACL will be managed.
