@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2016-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2016-2021 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: LGPL-2.0-or-later
 
@@ -7,18 +7,19 @@
 #ifndef ACLMODIFYJOB_H
 #define ACLMODIFYJOB_H
 
-#include <QObject>
-#include <KIMAP/Acl>
 #include <AkonadiCore/collection.h>
+#include <KIMAP/Acl>
+#include <QObject>
 class KJob;
-namespace PimCommon {
+namespace PimCommon
+{
 class ImapAclAttribute;
 class AclModifyJob : public QObject
 {
     Q_OBJECT
 public:
     explicit AclModifyJob(QObject *parent = nullptr);
-    ~AclModifyJob();
+    ~AclModifyJob() override;
 
     void setTopLevelCollection(const Akonadi::Collection &topLevelCollection);
     void setRecursive(bool recursive);
