@@ -2,7 +2,7 @@
   This file is part of libkdepim.
 
   SPDX-FileCopyrightText: 2006 Christian Schaarschmidt <schaarsc@gmx.de>
-  SPDX-FileCopyrightText: 2017-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2017-2021 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -16,7 +16,8 @@
 #include <QString>
 #include <QStringList>
 
-namespace PimCommon {
+namespace PimCommon
+{
 /**
  * KMailCompletion allows lookup of email addresses by keyword.
  * This is used for lookup by nickname, since we don't want the nickname to appear in the final email.
@@ -65,7 +66,7 @@ public:
     using KCompletion::postProcessMatches;
 
 private:
-    QMap< QString, QStringList > m_keyMap;
+    QMap<QString, QStringList> m_keyMap;
 };
 }
 
