@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2015-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: LGPL-2.0-or-later
 
@@ -12,27 +12,27 @@
 #include "blacklistbalooemailwarning.h"
 #include <Libkdepim/LineEditCatchReturnKey>
 
+#include "pimcommonakonadi_debug.h"
+#include <KConfigGroup>
+#include <KListWidgetSearchLine>
 #include <KLocalizedString>
+#include <KSharedConfig>
+#include <QHBoxLayout>
+#include <QLabel>
 #include <QLineEdit>
 #include <QPushButton>
-#include <QLabel>
-#include <QHBoxLayout>
 #include <QVBoxLayout>
-#include <KConfigGroup>
-#include <KSharedConfig>
-#include <KListWidgetSearchLine>
-#include "pimcommonakonadi_debug.h"
 
 using namespace PimCommon;
 BlackListBalooEmailCompletionWidget::BlackListBalooEmailCompletionWidget(QWidget *parent)
     : QWidget(parent)
 {
-    auto *mainLayout = new QVBoxLayout(this);
+    auto mainLayout = new QVBoxLayout(this);
 
-    auto *searchLayout = new QHBoxLayout;
+    auto searchLayout = new QHBoxLayout;
     mainLayout->addLayout(searchLayout);
 
-    QLabel *lab = new QLabel(i18n("Search email:"), this);
+    auto lab = new QLabel(i18n("Search email:"), this);
     lab->setObjectName(QStringLiteral("search_label"));
     searchLayout->addWidget(lab);
 
@@ -66,10 +66,10 @@ BlackListBalooEmailCompletionWidget::BlackListBalooEmailCompletionWidget(QWidget
     connect(mBlackListWarning, &BlackListBalooEmailWarning::saveChanges, this, &BlackListBalooEmailCompletionWidget::slotSaveChanges);
     mainLayout->addWidget(mBlackListWarning);
 
-    auto *searchLineLayout = new QHBoxLayout;
+    auto searchLineLayout = new QHBoxLayout;
     mainLayout->addLayout(searchLineLayout);
 
-    auto *selectElementLayout = new QHBoxLayout;
+    auto selectElementLayout = new QHBoxLayout;
     searchLineLayout->addLayout(selectElementLayout);
 
     mSelectButton = new QPushButton(i18n("&Select"), this);
@@ -105,11 +105,11 @@ BlackListBalooEmailCompletionWidget::BlackListBalooEmailCompletionWidget(QWidget
     searchLineLayout->addWidget(mNumberOfEmailsFound);
     searchLineLayout->addWidget(mSearchInResultLineEdit);
 
-    auto *excludeDomainLayout = new QHBoxLayout;
+    auto excludeDomainLayout = new QHBoxLayout;
     excludeDomainLayout->setContentsMargins(0, 0, 0, 0);
     mainLayout->addLayout(excludeDomainLayout);
 
-    QLabel *excludeDomainLabel = new QLabel(i18n("Exclude domain names:"), this);
+    auto excludeDomainLabel = new QLabel(i18n("Exclude domain names:"), this);
     excludeDomainLabel->setObjectName(QStringLiteral("domain_label"));
     excludeDomainLayout->addWidget(excludeDomainLabel);
 
@@ -179,7 +179,7 @@ void BlackListBalooEmailCompletionWidget::slotSearch()
     const QString searchEmail = mSearchLineEdit->text().trimmed();
     if (searchEmail.length() > 2) {
         mSearchInResultLineEdit->clear();
-        auto *job = new PimCommon::BlackListBalooEmailSearchJob(this);
+        auto job = new PimCommon::BlackListBalooEmailSearchJob(this);
         job->setSearchEmail(searchEmail);
         job->setLimit(mLimit);
         connect(job, &BlackListBalooEmailSearchJob::emailsFound, this, &BlackListBalooEmailCompletionWidget::slotEmailFound);
@@ -208,7 +208,7 @@ void BlackListBalooEmailCompletionWidget::setEmailBlackList(const QStringList &l
 
 void BlackListBalooEmailCompletionWidget::slotSaveChanges()
 {
-    //TODO avoid to save a lot.
+    // TODO avoid to save a lot.
     const QHash<QString, bool> result = mEmailList->blackListItemChanged();
     KSharedConfig::Ptr config = KSharedConfig::openConfig(QStringLiteral("kpimbalooblacklist"));
     KConfigGroup group(config, "AddressLineEdit");
@@ -236,11 +236,7 @@ void BlackListBalooEmailCompletionWidget::slotCheckIfUpdateBlackListIsNeeded()
 void BlackListBalooEmailCompletionWidget::save()
 {
     const QString domain = mExcludeDomainLineEdit->text().remove(QLatin1Char(' '));
-#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
-    const QStringList newExcludeDomain = domain.split(QLatin1Char(','), QString::SkipEmptyParts);
-#else
     const QStringList newExcludeDomain = domain.split(QLatin1Char(','), Qt::SkipEmptyParts);
-#endif
     bool needToSave = (mOriginalExcludeDomain != newExcludeDomain);
     KSharedConfig::Ptr config = KSharedConfig::openConfig(QStringLiteral("kpimbalooblacklist"));
     KConfigGroup group(config, "AddressLineEdit");
